@@ -55,7 +55,7 @@ describe('Lookahead iterator', () => {
     const cursor = tree.walk();
     assert(cursor.gotoFirstChild());
     assert(cursor.gotoFirstChild());
-    state = cursor.currentNode().nextParseState;
+    state = cursor.currentNode.nextParseState;
     lookahead = JavaScript.lookaheadIterator(state);
     assert.exists(lookahead);
   });
